Facebook Album Plugin for django CMS
====================================


This is a Facebook Album plugin to show images from a facebook page
album in `django CMS`_. It enables all images to be presented in
a attractive way so that it could be used in thumbnails and
presented in a lightbox.
